@@ -6,7 +6,7 @@ import mlflow
 from waveletai._version import get_versions
 from waveletai import constants, envs
 from waveletai.backends.hosted_backend import HostedBackend
-from waveletai.constants import ModelRegisterMode
+from waveletai.constants import ModelRegisterMode, Visibility
 from waveletai.exceptions import InitFailed
 from waveletai.sessions import Session
 from waveletai.utils import MLflowModuleRegister, set_mlflow_tracing_waveletai_store
@@ -85,15 +85,16 @@ def set_model(model_id):
     return _get_backend().set_model(model_id)
 
 
-def create_app(name, tags, desc=None):
+def create_app(name, tags, desc=None, visibility=Visibility.PRIVATE.value):
     """
     创建应用
     :param name :str 应用名称
     :param tags :list 应用标签
     :param desc :str 应用说明
+    :param visibility: 公有私有 public private 默认 private
     :return: App对象
     """
-    return _get_backend().create_app(name, tags, desc)
+    return _get_backend().create_app(name, tags, desc, visibility)
 
 
 def update_app(name, tags, desc=None):
@@ -122,7 +123,7 @@ def get_app():
     return _get_backend().get_app()
 
 
-def create_dataset(name, path, data_type=constants.DataType.TYPE_FILE.value, visibility='private', desc=None):
+def create_dataset(name, path, data_type=constants.DataType.TYPE_FILE.value, visibility=Visibility.PRIVATE.value, desc=None):
     """
     创建数据集
     :param name: 数据集名称
@@ -177,9 +178,10 @@ def upload_dataset_artifacts(dataset_id, path):
     return _get_backend().upload_dataset_artifacts(dataset_id, path)
 
 
-def create_model(name, desc=None, auth_id=None, git_url=None, http_url=None):
+def create_model(name, desc=None, git_url=None, http_url=None, visibility=Visibility.PRIVATE.value):
     """
     创建模型
+    :param visibility: 公有私有 public private 默认 private
     :param http_url: http地址 默认空
     :param git_url: git地址 默认空
     :param auth_id: auth_id 默认空
@@ -187,7 +189,7 @@ def create_model(name, desc=None, auth_id=None, git_url=None, http_url=None):
     :param desc:模型备注 默认空
     :return:
     """
-    return _get_backend().create_model(name, desc, auth_id, git_url, http_url)
+    return _get_backend().create_model(name, desc, git_url, http_url, visibility)
 
 
 def get_model():
