@@ -13,6 +13,7 @@ import json
 import logging
 import os
 import platform
+import socket
 # import retrying
 from waveletai import envs
 from waveletai.model import Model
@@ -41,16 +42,17 @@ _logger = logging.getLogger(__name__)
 class HostedBackend(Backend):
 
     @with_api_exceptions_handler
-    def create_app(self, name, tags, desc):
+    def create_app(self, name, tags, desc, visibility):
         """
         : 添加新应用
         :param name str 应用名称
         :param tags list 应用标签
         :param desc str 应用描述
+        :param visibility: 公有私有 public private 默认 private
         :return: Class `app` Object
         """
         res = self._session.post(url=f'{self.api_address}/application/app/',
-                                 json={"name": name, "tags": tags, "desc": desc})
+                                 json={"name": name, "tags": tags, "desc": desc, "visibility": visibility})
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         data = res.json()['data']
@@ -507,6 +509,16 @@ class HostedBackend(Backend):
         except Exception as e:
             raise e
 
+    @with_api_exceptions_handler
+    def _get_ip(self):
+        try:
+            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+            s.connect(('8.8.8.8', 80))
+            ip = s.getsockname()[0]
+        finally:
+            s.close()
+        return ip
+
     @with_api_exceptions_handler
     @require_app
     def _list_dir_artifacts(self, dataset_id, path, result, dir):
@@ -543,7 +555,9 @@ class HostedBackend(Backend):
         :param dataset_id:
         :return: 返回文件，图片数据集文件列表
         """
-        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/dataset/{dataset_id}/asset?page=-1')
+        client_ip = self._get_ip()
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/dataset/{dataset_id}/asset?page=-1',
+                                headers={"client-ip": client_ip})
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         artifacts = []
@@ -579,9 +593,10 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     @require_app
-    def create_model(self, name, desc, auth_id, git_url, http_url):
+    def create_model(self, name, desc, git_url, http_url, visibility):
         """
         当前应用下创建模型
+        :param visibility: 公有私有 public private 默认 private
         :param name:模型名称
         :param desc:模型备注
         :param auth_id: auth_id 默认空
@@ -592,9 +607,9 @@ class HostedBackend(Backend):
         res = self._session.post(url=f'{self.api_address}/{self.app_id}/training/model/', json={"name": name,
                                                                                                 "app_id": self.app_id,
                                                                                                 "desc": desc,
-                                                                                                "auth_id": auth_id,
                                                                                                 "git_url": git_url,
-                                                                                                "http_url": http_url})
+                                                                                                "http_url": http_url,
+                                                                                                "visibility": visibility})
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
